/** @hidden */
export declare function stringifyInternal<Ts>(value: Ts, previousValues: any[]): string;
/**
 * Convert any value to its fast-check string representation
 * @param value Value to be converted into a string
 */
export declare function stringify<Ts>(value: Ts): string;
