/** @hidden */
export declare const buildLowerAlphaArb: (others: string[]) => import("../definition/Arbitrary").Arbitrary<string>;
/** @hidden */
export declare const buildLowerAlphaNumericArb: (others: string[]) => import("../definition/Arbitrary").Arbitrary<string>;
/** @hidden */
export declare const buildAlphaNumericArb: (others: string[]) => import("../definition/Arbitrary").Arbitrary<string>;
/** @hidden */
export declare const buildAlphaNumericPercentArb: (others: string[]) => import("../definition/Arbitrary").Arbitrary<string>;
