"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
exports.__esModule = true;
var prand = require("./pure-rand-default");
exports["default"] = prand;
__export(require("./pure-rand-default"));
