"use strict";
exports.__esModule = true;
var TupleArbitrary_generated_1 = require("./TupleArbitrary.generated");
exports.tuple = TupleArbitrary_generated_1.tuple;
var TupleArbitrary_generic_1 = require("./TupleArbitrary.generic");
exports.genericTuple = TupleArbitrary_generic_1.genericTuple;
