"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var fc = require("./fast-check-default");
exports["default"] = fc;
tslib_1.__exportStar(require("./fast-check-default"), exports);
