/** @hidden */
export declare const ObjectEntriesImpl: (obj: any) => [string, any][];
/** @hidden */
export declare const ObjectEntries: (obj: any) => [string, any][];
/** @hidden */
export declare const StringPadEndImpl: (src: string, targetLength: number, padString: string) => string;
/** @hidden */
export declare const StringPadStartImpl: (src: string, targetLength: number, padString: string) => string;
/** @hidden */
export declare const StringPadEnd: (src: string, targetLength: number, padString: string) => string;
/** @hidden */
export declare const StringPadStart: (src: string, targetLength: number, padString: string) => string;
/** @hidden */
export declare const StringFromCodePointLimitedImpl: (codePoint: number) => string;
/** @hidden */
export declare const StringFromCodePointLimited: (...codePoints: number[]) => string;
